@@ -157,13 +157,19 @@ class Service(web.Application):
 
         handlers.append((r"/.*", NotFoundHandler))
 
+        super().__init__(handlers=handlers, debug=True if self.ENVIRONMENT in ['local', 'dev'] else False,
+                         xsrf_cookies=False, logging=self.logging, **kwargs)
+
         if os.getenv("REDIS_URL"):
+            self.logging.info("[PLUGINS] Redis enabled")
             self.redis = Redis(prefix=os.getenv("REDIS_PREFIX"), url=os.getenv("REDIS_URL"))
 
         if os.getenv("MONGODB_URL"):
+            self.logging.info("[PLUGINS] MongoDB enabled")
             self.mongo = MongoDB(url=os.getenv("MONGODB_URL"))
 
         if os.getenv('SENTRY_DSN_URL'):
+            self.logging.info("[PLUGINS] Sentry enabled")
             sentry_sdk.init(
                 dsn=os.getenv('SENTRY_DSN_URL'),
                 environment=self.ENVIRONMENT,
@@ -176,6 +182,7 @@ class Service(web.Application):
 
         if os.getenv("DATADOG_ENABLED"):
             if os.getenv("DATADOG_SERVICE_NAME") and os.getenv("DATADOG_API_KEY") and os.getenv("DATADOG_APP_KEY"):
+                self.logging.info("[PLUGINS] DataDog enabled")
                 self.monitor = DataDogMonitor(
                     host=os.getenv("DATADOG_HOST", '127.0.0.1'),
                     service=os.getenv("DATADOG_SERVICE_NAME"),
@@ -184,9 +191,6 @@ class Service(web.Application):
                     app_key=os.getenv("DATADOG_APP_KEY")
                 )
 
-        super().__init__(handlers=handlers, debug=True if self.ENVIRONMENT in ['local', 'dev'] else False,
-                         xsrf_cookies=False, logging=self.logging, **kwargs)
-
         host = os.getenv('SERVICE_HOST', '0.0.0.0')
         if not kwargs.get('bind_port'):
             try:
@@ -197,6 +201,13 @@ class Service(web.Application):
             port = kwargs.get('bind_port')
 
         self.logging.info(f"Starting {self.NAME.capitalize()} service on [{host}:{port}]")
+
+        self.logging.info("Available routes:")
+        for row in handlers:
+            if 'ping' in row[0] or row[0] == r"/.*":
+                continue
+            self.logging.info(f" * {row[0]}")
+
         self.listen(address=host, port=port)
         for queue in queues:
             self.io_loop.add_callback(queue)
@@ -453,10 +464,19 @@ class Endpoint(web.RequestHandler):
                     uuid.UUID(result, version=4)
                 except (TypeError, ValueError, AttributeError):
                     raise ValidationException(field=name, message="Invalid UUID value")
+            elif argument_type == 'email':
+                regex = r'\b[A-Za-z0-9._%+-]+@[A-Za-z0-9.-]+\.[A-Z|a-z]{2,}\b'
+                if not re.fullmatch(regex, result):
+                    raise ValidationException(field=name, message="Invalid email")
 
         if required and not result:
             raise ValidationException(field=name, message="Field is required and should not be empty")
 
+        if argument_type in ['email']:
+            if not process:
+                process = []
+            process.extend(['lower', 'strip'])
+
         if result is not None and argument_type is str and process:
             if 'capitalize_first' in process:
                 result = result.capitalize()
